@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import logging
 import platform
 import sys
 
@@ -15,7 +16,10 @@ from poetry.__version__ import __version__
 from poetry.utils._compat import WINDOWS
 
 
+logger = logging.getLogger(__name__)
+
 if TYPE_CHECKING:
+    from collections.abc import Collection
     from typing import BinaryIO
 
     from installer.records import RecordEntry
@@ -42,9 +46,9 @@ class WheelDestination(SchemeDictionaryDestination):
 
         target_path = Path(self.scheme_dict[scheme]) / path
         if target_path.exists():
-            # Contrary to the base library we don't raise an error
-            # here since it can break namespace packages (like Poetry's)
-            pass
+            # Contrary to the base library we don't raise an error here since it can
+            # break pkgutil-style and pkg_resource-style namespace packages.
+            logger.warning(f"Installing {target_path} over existing file")
 
         parent_folder = target_path.parent
         if not parent_folder.exists():
@@ -60,18 +64,6 @@ class WheelDestination(SchemeDictionaryDestination):
 
         return RecordEntry(path, Hash(self.hash_algorithm, hash_), size)
 
-    def for_source(self, source: WheelFile) -> WheelDestination:
-        scheme_dict = self.scheme_dict.copy()
-
-        scheme_dict["headers"] = str(Path(scheme_dict["headers"]) / source.distribution)
-
-        return self.__class__(
-            scheme_dict,
-            interpreter=self.interpreter,
-            script_kind=self.script_kind,
-            bytecode_optimization_levels=self.bytecode_optimization_levels,
-        )
-
 
 class WheelInstaller:
     def __init__(self, env: Env) -> None:
@@ -85,18 +77,13 @@ class WheelInstaller:
                 script_kind = "win-arm64" if sys.maxsize > 2**32 else "win-arm"
             else:
                 script_kind = "win-amd64" if sys.maxsize > 2**32 else "win-ia32"
+        self._script_kind = script_kind
 
-        schemes = self._env.paths
-        schemes["headers"] = schemes["include"]
-
-        self._destination = WheelDestination(
-            schemes, interpreter=str(self._env.python), script_kind=script_kind
-        )
-
+        self._bytecode_optimization_levels: Collection[int] = ()
         self.invalid_wheels: dict[Path, list[str]] = {}
 
     def enable_bytecode_compilation(self, enable: bool = True) -> None:
-        self._destination.bytecode_optimization_levels = (-1,) if enable else ()
+        self._bytecode_optimization_levels = (-1,) if enable else ()
 
     def install(self, wheel: Path) -> None:
         with WheelFile.open(wheel) as source:
@@ -107,9 +94,21 @@ class WheelInstaller:
                 source.validate_record(validate_contents=False)
             except _WheelFileValidationError as e:
                 self.invalid_wheels[wheel] = e.issues
+
+            scheme_dict = self._env.paths.copy()
+            scheme_dict["headers"] = str(
+                Path(scheme_dict["include"]) / source.distribution
+            )
+            destination = WheelDestination(
+                scheme_dict,
+                interpreter=str(self._env.python),
+                script_kind=self._script_kind,
+                bytecode_optimization_levels=self._bytecode_optimization_levels,
+            )
+
             install(
                 source=source,
-                destination=self._destination.for_source(source),
+                destination=destination,
                 # Additional metadata that is generated by the installation tool.
                 additional_metadata={
                     "INSTALLER": f"Poetry {__version__}".encode(),
